@@ -265,7 +265,7 @@ class PurchaseRequisition(Workflow, ModelSQL, ModelView):
 
     @fields.depends('lines', 'currency')
     def on_change_with_total_amount(self):
-        self.total_amount = Decimal('0.0')
+        self.total_amount = Decimal(0)
         if self.lines:
             for line in self.lines:
                 self.total_amount += getattr(line, 'amount', None) or 0
@@ -360,6 +360,7 @@ class PurchaseRequisition(Workflow, ModelSQL, ModelView):
         default.setdefault('supply_date', None)
         default.setdefault('approved_by')
         default.setdefault('rejected_by')
+        default.setdefault('total_amount_cache')
         return super(PurchaseRequisition, cls).copy(
             requisitions, default=default)
 
@@ -374,7 +375,11 @@ class PurchaseRequisition(Workflow, ModelSQL, ModelView):
     @Workflow.transition('draft')
     @reset_employee('approved_by', 'rejected_by')
     def draft(cls, requisitions):
-        pass
+        cls.write(requisitions, {
+                'tax_amount_cache': None,
+                'untaxed_amount_cache': None,
+                'total_amount_cache': None,
+                })
 
     @classmethod
     @ModelView.button
